%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Class-specific
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{CIES}[2009/04/01 Format and some usefull macros for CIES beamer presentation]

\RequirePackage{etex}

\newif\ifarticle
\newif\ifMikTeX

\DeclareOption{article}{\global\articletrue}
\DeclareOption{miktex}{\global\MikTeXtrue}

\DeclareOption*{
  \ifarticle%
    \PassOptionsToClass{\CurrentOption}{article}%
  \else%
    \PassOptionsToClass{\CurrentOption}{beamer}%
  \fi%
}

\ProcessOptions\relax

\ifarticle
  \LoadClass{article}
  \RequirePackage{beamerarticle}
  \let\titlepage=\maketitle
\else
  \LoadClass{beamer}
\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Beamer setup
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\usecolortheme{rose}

\setbeamerfont{block body example}{family=\sffamily}
\setbeamerfont{block body alerted}{size=\fontsize{7}{8}\selectfont,family=\rmfamily}

\mode
<handout>

  \RequirePackage{pgfpages}
  \pgfpagesuselayout{4 on 1}[a4paper,landscape]

\mode
<beamer>

  \usecolortheme[overlystylish]{albatross}
  \useinnertheme[shadow]{rounded}

  \setbeamercolor{block body example}{fg=black,bg=white}

  \AtBeginSection{%
    \begin{frame}%
      \frametitle{Table des matires}%
      \tableofcontents[sectionstyle=show/shaded,subsectionstyle=show/shaded/hide]%
    \end{frame}%
  }

  \AtBeginSubsection{%
    \begin{frame}%
      \frametitle{Table des matires}%
      \tableofcontents[sectionstyle=show/shaded,subsectionstyle=show/shaded/hide]%
    \end{frame}%
  }

\mode
<all>

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Listings setup
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{listings,color}

\lstdefinestyle{latex}{
  language=[LaTeX]TeX,
  breaklines,
  showspaces,
  basicstyle=\footnotesize\ttfamily,
  extendedchars,
  escapechar=,
  aboveskip=0pt,
  belowskip=0pt
}

\lstdefinestyle{default}{
  breaklines=true,
  showspaces=false,
  basicstyle=\footnotesize,
  aboveskip=0pt,
  belowskip=0pt,
  keywordstyle=\color{red},
  commentstyle=\color{green},
  identifierstyle=\color{blue}
}

\mode
<beamer>

  \lstdefinestyle{latex}{
    language=[LaTeX]TeX,
    breaklines,
    showspaces,
    basicstyle=\footnotesize\color{white}\ttfamily,
    extendedchars,
    escapechar=,
    aboveskip=0pt,
    belowskip=0pt,
    keywordstyle=\color{red},
    commentstyle=\color{green},
    identifierstyle=\color{yellow}
  }

  \lstdefinestyle{default}{
    breaklines=true,
    showspaces=false,
    basicstyle=\footnotesize\color{black},
    aboveskip=0pt,
    belowskip=0pt,
    keywordstyle=\color{red},
    commentstyle=\color{green},
    identifierstyle=\color{blue}
  }

\mode
<all>

\lstset{style=latex}

\lstnewenvironment{latex}{\lstset{style=latex}}{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Verbatim writer
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{verbatim,ifpdf}
\ifpdf
  \RequirePackage{attachfile2}
\else
  \RequirePackage[dvips]{attachfile2}
\fi

\newwrite\verbatim@out

\newcounter{verbatim@file}

\def\verbatim@file{%
  tmp\theverbatim@file.tex%
}

\ifarticle
  \def\vebatim@file@link{}
\else
  \def\vebatim@file@link{%
    \attachfile[scale=0.6]{\external@file}%
    \tiny Fichier \expandafter\url\expandafter{\external@file}%
  }
\fi

\mode
<beamer>

\def\external@file{%
  \jobname/code\theverbatim@file.tex%
}

\def\copy@external{%
  \ifMikTeX%
    \immediate\write18{copy \verbatim@file\space\external@file}%
  \else%
    \immediate\write18{cp \verbatim@file\space\external@file}%
  \fi%
}

\mode
<all>

\def\verbatim@open{%
  \stepcounter{verbatim@file}%
  \immediate\openout\verbatim@out\verbatim@file\relax%
}

\def\verbatim@close{%
  \immediate\closeout\verbatim@out\relax%
}

\newenvironment{verbatim@write}{%
  \bgroup%
  \@bsphack%
  \let\do\@makeother\dospecials%
  \catcode`\^^M\active%
  \def\verbatim@processline{%
    \immediate\write\verbatim@out{\the\verbatim@line}%
  }%
  \verbatim@start%
}{%
  \@esphack%
  \egroup%
}

\renewenvironment{latex}{%
  \verbatim@open%
  \verbatim@write%
}{%
  \endverbatim@write%
  \verbatim@close%
  \lstinputlisting[style=latex]{\verbatim@file}%
}

\newenvironment{latexblock}[1]{%
  \def\latex@blockcaption{#1}%
  \verbatim@open%
  \verbatim@write%
}{%
  \endverbatim@write%
  \verbatim@close%
  \begin{codeblock}[\latex@blockcaption]%
    \lstinputlisting[style=latex]{\verbatim@file}%
  \end{codeblock}%
}

\mode
<beamer>

\ifMikTeX
  \immediate\write18{mkdir \jobname}
  \immediate\write18{del \jobname/code*.tex}
  \AtEndDocument{%
    \immediate\write18{del tmp*.tex}
  }
\else
  \immediate\write18{md \jobname}
  \immediate\write18{rm \jobname/code*.tex}
  \AtEndDocument{%
    \immediate\write18{rm tmp*.tex}
  }
\fi

\renewenvironment{latex}{%
  \verbatim@open%
  \verbatim@write%
}{%
  \endverbatim@write%
  \verbatim@close%
  \par%
  \copy@external%
  \vebatim@file@link%
  \lstinputlisting[style=latex]{\verbatim@file}%
}

\renewenvironment{latexblock}[1]{%
  \def\latex@blockcaption{#1}%
  \verbatim@open%
  \verbatim@write%
}{%
  \endverbatim@write%
  \verbatim@close%
  \copy@external%
  \begin{codeblock}[\latex@blockcaption\hfill\vebatim@file@link]%
    \lstinputlisting[style=latex]{\verbatim@file}%
  \end{codeblock}%
}

\mode
<all>

\newenvironment{verbatimblock}[1]{%
  \def\verbatim@blockcaption{#1}%
  \verbatim@open%
  \verbatim@write%
}{%
  \endverbatim@write%
  \verbatim@close%
  \begin{codeblock}[\verbatim@blockcaption]%
    \verbatiminput{\verbatim@file}%
  \end{codeblock}%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Code and demo blocks
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newenvironment{codeblock}[1][Code]{%
  \begin{alertblock}{#1}%
    \ignorespaces%
}{%
  \end{alertblock}%
}

\newenvironment{demoblock}[1][Sortie]{%
  \begin{exampleblock}{#1}%
    \begin{minipage}{\textwidth}%
      \parskip0.5ex%
      \ignorespaces%
}{%
    \end{minipage}%
  \end{exampleblock}%
}

\newif\if@dummycode\@dummycodefalse

\newenvironment{dummycode}{%
  \global\@dummycodetrue%
  \verbatim@open%
  \verbatim@write%
}{%
  \endverbatim@write%
  \verbatim@close%
}

\def\print@code{%
  \if@dummycode%
    \global\@dummycodefalse%
    \addtocounter{verbatim@file}{-1}%
    \begin{codeblock}%
      \lstinputlisting[style=latex]{\verbatim@file}%
    \end{codeblock}%
    \stepcounter{verbatim@file}%
  \else%
    \begin{codeblock}%
      \lstinputlisting[style=latex]{\verbatim@file}%
    \end{codeblock}%
  \fi%
}%

\mode
<beamer>

\def\print@code{%
  \if@dummycode%
    \global\@dummycodefalse%
    \addtocounter{verbatim@file}{-1}%
    \copy@external%
    \begin{codeblock}[Code\hfill\vebatim@file@link]%
      \lstinputlisting[style=latex]{\verbatim@file}%
    \end{codeblock}%
    \stepcounter{verbatim@file}%
  \else%
    \copy@external%
    \begin{codeblock}[Code\hfill\vebatim@file@link]%
      \lstinputlisting[style=latex]{\verbatim@file}%
    \end{codeblock}%
  \fi%
}%

\mode
<all>

\newenvironment{demo}{%
  \verbatim@open%
  \verbatim@write%
}{%
  \endverbatim@write%
  \verbatim@close%
  \begin{columns}%
    \begin{column}{0.55\textwidth}%
      \print@code%
    \end{column}%
    \begin{column}{0.465\textwidth}%
      \begin{demoblock}%
        \input{\verbatim@file}%
      \end{demoblock}%
    \end{column}%
  \end{columns}%
}

\newenvironment{frame-demo}[1]{%
  \global\def\@framedemotitle{#1}%
  \verbatim@open%
  \verbatim@write%
}{%
  \endverbatim@write%
  \verbatim@close%
  \begin{frame}%
    \frametitle{\@framedemotitle}%
    \print@code%
  \end{frame}%
  \begin{frame}%
    \frametitle{Sortie}%
    \input{\verbatim@file}%
  \end{frame}%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Exercices
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newif\ifexercicehard

\def\exercicetitle{%
  \ifexercicehard%
    \frametitle{Exercice [\alert{\bfseries\small Difficile}]}%
  \else
    \frametitle{Exercice}%
  \fi%
}

\newenvironment{exercice}[2][fragile,environment=exercice]{%
  \begin{frame}[#1]%
    \exercicetitle%
    \framesubtitle{#2}%
}{%
  \end{frame}%
  \global\exercicehardfalse%
}

\newenvironment{exercice-double}{%
  \def\question##1{%
    \begin{frame}[containsverbatim]%
    \exercicetitle%
    \framesubtitle{##1}%
    \ignorespaces%
  }
  \def\endquestion{%
    \end{frame}%
  }%
  \def\answer##1{%
    \begin{frame}[containsverbatim]%
    \frametitle{Solution}%
    \framesubtitle{##1}%
    \ignorespaces%
  }
  \def\endanswer{%
    \end{frame}%
  }%
}{%
  \global\exercicehardfalse%
}

\newenvironment{exercice-findcode}[1]{%
  \global\def\@question{#1}%
  \verbatim@open%
  \verbatim@write%
}{%
  \endverbatim@write%
  \verbatim@close%
  \begin{frame}%
    \exercicetitle%
    \framesubtitle{\@question}%
  \end{frame}%
  \begin{frame}[containsverbatim]%
    \frametitle{Solution}%
    \framesubtitle{\@question}%
    \print@code%
  \end{frame}%
  \global\exercicehardfalse%
}

\newenvironment{exercice-reversecode}{%
  \def\exercice@caption{Trouver le code pour obtenir la sortie suivante}%
  \verbatim@open%
  \verbatim@write%
}{%
  \endverbatim@write%
  \verbatim@close%
  \begin{frame}%
    \exercicetitle%
    \framesubtitle{\exercice@caption}%
    \begin{demoblock}%
      \input{\verbatim@file}%
    \end{demoblock}%
  \end{frame}%
  \begin{frame}[containsverbatim]%
    \frametitle{Solution}%
    \print@code%
  \end{frame}%
  \global\exercicehardfalse%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Seminar
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{filecontents,graphicx}

\newif\ifcompileseminar
\compileseminartrue

\newcounter{seminar@file}

\begin{filecontents}{seminartheme.tex}
\documentclass[a4]{seminar}
\usepackage{semcolor,slidesec,fancybox,pst-grad}
\input{seminar.bug}
\input{seminar.bg2}
\def\printlandscape{\special{papersize=297mm,210mm}}
\usepackage[francais]{babel}
\usepackage[latin1]{inputenc}
\usepackage[T1]{fontenc}
\pagestyle{align}
\input{seminartheme-config}
\begin{document}
\begin{slide*}
  \slideheading{La classe \texttt{seminar}}
  \slidesubheading{Nouveaux environnements}
  \begin{itemize}
    \item\verb|\begin{slide}|{\gray\verb|[largeur,hauteur]|} pour ajouter un transparent supplmentaire en mode <<~paysage~>>;
    \item\verb|\begin{slide*}|{\gray\verb|[largeur,hauteur]|} idem mais en mode <<~portrait~>>;
    \item\verb|\begin{note}| pour ajouter une note. 
  \end{itemize}\bigskip
  \slidesubheading{Options}
  \begin{itemize}
    \item{\blue\verb|notes|} pour imprimer notes et transparents;
    \item\verb|slidesonly| pour n'imprimer que les transparents;
    \item\verb|notesonly| pour n'imprimer que les notes;
    \item\verb|article| pour imprimer un article dont le corps est form du contenu des notes avec les transparents en figures flottantes.
  \end{itemize}
\end{slide*}
\end{document}
\end{filecontents}

\newcommand\showseminar[3][]{%
  \stepcounter{seminar@file}%
  \ifcompileseminar%
    \edef\@empty{}%
    \edef\@temp{#3}%
    \immediate\openout\verbatim@out seminartheme-config.tex\relax%
    \ifx\@temp\@empty%
    \else%
      \immediate\write\verbatim@out{\string\slideframe[\string\psset{#2}]{#3}}%
    \fi%
    \immediate\closeout\verbatim@out%
    \immediate\write18{latex -interaction=batchmode seminartheme}%
    \immediate\write18{dvips -Ppdf -o seminartheme\theseminar@file.ps seminartheme.dvi}%
  \fi%
  \includegraphics[#1]{seminartheme\theseminar@file.ps}%
}

\begingroup
\catcode`#=11
\gdef\seminar@patch{%
  \immediate\write\verbatim@out{%
    \noexpand\newslideframe{CIES}{%
      \noexpand\rput(1.5,-0.4){%
        \noexpand\psovalbox[fillstyle=solid,fillcolor=blue]{\noexpand\white\noexpand\LARGE\noexpand\bfseries CIES}%
      }%
      #1%
    }%
  }%
}%
\endgroup

\newcommand\showCIESseminar[1][]{%
  \stepcounter{seminar@file}%
  \ifcompileseminar%
    \immediate\openout\verbatim@out seminartheme-config.tex\relax%
    \seminar@patch%
    \immediate\write\verbatim@out{\noexpand\slideframe{CIES}}%
    \immediate\write\verbatim@out{\noexpand\slideframe*[\noexpand\psset{fillstyle=gradient,gradbegin=orange,gradend=white,gradmidpoint=0.5}]{scplain}}%
    \immediate\closeout\verbatim@out%
    \immediate\write18{latex -interaction=batchmode seminartheme}%
    \immediate\write18{dvips -Ppdf -o seminartheme\theseminar@file.ps seminartheme.dvi}%
  \fi%
  \includegraphics[#1]{seminartheme\theseminar@file.ps}%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Beamer
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{filecontents,graphicx}

\newif\ifcompilebeamer
\compilebeamertrue

\newcounter{beamer@file}

\begin{filecontents}{beamertheme.tex}
\documentclass{beamer}
\usepackage[francais]{babel}
\usepackage[latin1]{inputenc}
\usepackage[T1]{fontenc} 
\title{Utilisation de Beamer}
\author{Vincent Feuvrier}
\institute{CIES}
\date{\today}
\input{beamertheme-config.tex}
\AtBeginSection{%
\begin{frame}{Sommaire}%
\tableofcontents%
\end{frame}%
}
\AtBeginSubsection{%
\begin{frame}{Sommaire}%
\tableofcontents%
\end{frame}%
}
\begin{document}
\begin{frame}
\titlepage
\end{frame}
\section{Les bases}
\subsection{La page de titre}
\subsection{Le sommaire}
\subsection{Les thmes}
\section{Les frames}
\subsection{Les titres}
\subsection{Les colonnes}
\begin{frame}
\frametitle{Colonnes}
\framesubtitle{Pour utiliser au mieux l'espace disponible}
Du texte sur deux colonnes, avec des blocs pour le mettre en vidence.\bigskip\par
\begin{columns}
\begin{column}{0.5\textwidth}
\begin{exampleblock}{Bloc d'exemple}
Une numration dans le bloc
\begin{enumerate}
\item Une
\begin{enumerate}
\item Une
\item numration
\item imbrique
\end{enumerate}
\item numration
\item basique
\end{enumerate}
\end{exampleblock}
\end{column}
\begin{column}{0.5\textwidth}
\begin{alertblock}{Bloc d'alerte}
Une liste dans le bloc
\begin{itemize}
\item Une
\begin{itemize}
\item Une
\item liste
\item imbrique
\end{itemize}
\item liste
\item basique
\end{itemize}
\end{alertblock}
\end{column}
\end{columns}
\end{frame}
\subsection{Les blocks}
\section{Les animations}
\subsection{La commande \ttfamily\textbackslash pause}
\subsection{L'affichage diffr}
\subsection{Les recouvrements}
\end{document}
\end{filecontents}

\def\beamer@writetheme#1#2{%
  \edef\@empty{}%
  \edef\@temp{#2}%
  \ifx\@temp\@empty\relax%
  \else%
    \immediate\write\verbatim@out{%
      \expandafter\noexpand\csname #1\endcsname#2%
    }%
  \fi%
}

\newcommand\show@beamer[6]{%
  \stepcounter{beamer@file}%
  \ifcompilebeamer%
    \immediate\openout\verbatim@out beamertheme-config.tex\relax%
    \beamer@writetheme{usetheme}{#2}%
    \beamer@writetheme{usecolortheme}{#3}%
    \beamer@writetheme{useinnertheme}{#4}%
    \beamer@writetheme{useoutertheme}{#5}%
    \beamer@writetheme{usefonttheme}{#6}%
    \immediate\closeout\verbatim@out%
    \immediate\write18{latex -interaction=batchmode beamertheme}%
    \immediate\write18{dvips -Ppdf -pp9 -T 128mm,96mm -E -o beamertheme\thebeamer@file.ps beamertheme.dvi}%
  \fi%
  \includegraphics[#1]{beamertheme\thebeamer@file.ps}%
}

\newcommand\showbeamertheme[2][]{%
  \show@beamer{#1}{{#2}}{}{}{{sidebar}}{}%
}

\newcommand\showbeamercolortheme[3][]{%
  \show@beamer{#1}{}{[#2]{#3}}{}{{sidebar}}{}%
}

\newcommand\showbeamerinnertheme[3][]{%
  \show@beamer{#1}{}{{orchid}}{[#2]{#3}}{}{}%
}

\newcommand\showbeameroutertheme[3][]{%
  \show@beamer{#1}{}{{dolphin}}{}{[#2]{#3}}{}%
}

\newcommand\showbeamerfonttheme[3][]{%
  \show@beamer{#1}{}{}{}{}{[#2]{#3}}%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fonts
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\@ffa@bch{Charter}
\def\@ffa@b{Charter bold}
\def\@ffa@ccr{Concrete}
\def\@ffa@cmdh{Computer Modern dunhil}
\def\@ffa@cmfr{Computer Modern funny roman}
\def\@ffa@cmr{Computer Modern roman}
\def\@ffa@cmsf{Computer Modern sans srif}
\def\@ffa@cmss{Computer Modern sans srif}
\def\@ffa@cmtt{Computer Modern typewriter}
\def\@ffa@lmr{Latin Modern roman}
\def\@ffa@lmss{Latin Modern sans srif}
\def\@ffa@lmtt{Latin Modern typewriter}
\def\@ffa@pag{Avant Garde}
\def\@ffa@pbk{Bookman}
\def\@ffa@pcr{Courier}
\def\@ffa@phv{Helvetica}
\def\@ffa@pnc{New Century}
\def\@ffa@ppl{Palatino}
\def\@ffa@ptm{Times}
\def\@ffa@pzc{Zapf Chancery}
\def\@ffa@pzd{Zapf Dingbats}
\def\@ffa@yfrak{Gothique}
\def\@ffa@rsfs{Ralph Smith's Formal Script}

\def\@fse@m{medium}
\def\@fse@b{bold}
\def\@fse@bx{bold extended}
\def\@fse@bc{bold condensed}
\def\@fse@sb{semi-bold}
\def\@fse@c{condensed}

\def\@fsh@n{normal}
\def\@fsh@it{italic}
\def\@fsh@sl{slanted}
\def\@fsh@sc{small capitals}

\newcommand\show@fontname[4]{%
  \ifcsname @ffa@#2\endcsname%
    {\color{green!40!black}\bfseries\csname @ffa@#2\endcsname}, %
    \csname @fse@#3\endcsname, %
    \csname @fsh@#4\endcsname\ %
    (\texttt{#1/#2/#3/#4})%
  \else%
    ---%
  \fi%
}

\newcommand\showfont[5][ABCDEFGHIJKL abcdefghijkl 0123456789]{%
  \show@fontname{#2}{#3}{#4}{#5}:%
  \hrule
  {%
    \Large%
    \usefont{#2}{#3}{#4}{#5}%
    \hfill #1\strut\smallskip\break%
  }%
}%

\newcommand\show@font[6]{%
  \edef\@temp{#3}%
  \edef\@empty{}%
  {\blue\ttfamily\textbackslash #6}: %
  \show@fontname{#2}{#3}{#4}{#5}%
  \hrule
  \ifx\@temp\@empty\relax%
    {%
      \Large%
      \hfill\alert{\bfseries Manquante}\strut\smallskip\break%
    }%
  \else%
    {%
      \Large%
      \usefont{#2}{#3}{#4}{#5}%
      \hfill #1\strut\smallskip\break%
    }%
  \fi%
}%

\newcommand\framefontpackagedemo[9][]{%
  \begin{frame}%
    \frametitle{Changer les fontes de tout le document avec une extension}%
    \def\@tempa{#1}%
    \def\@tempb{*}%
    \ifx\@tempa\@tempb\relax%
      \framesubtitle{Polices par dfaut}%
    \else%
      \framesubtitle{L'extension \sigle{#9}#1}%
    \fi%
    \begin{demoblock}[]%
      \noindent%
      \show@font{ABCDEFGHIJKL abcdefghijkl 0123456789}{T1}{#2}{m}{n}{rmfamily}%
      \show@font{ABCDEFGHIJKL abcdefghijkl 0123456789}{T1}{#3}{m}{n}{sffamily}%
      \show@font{ABCDEFGHIJKL abcdefghijkl 0123456789}{T1}{#4}{m}{n}{ttfamily}%
      \show@font{ABCDEFGHIJKL abcdefghijkl 0123456789}{T1}{#5}{b}{n}{bfseries}%
      \show@font{ABCDEFGHIJKL abcdefghijkl 0123456789}{T1}{#6}{m}{it}{itshape}%
      \show@font{ABCDEFGHIJKL abcdefghijkl 0123456789}{T1}{#7}{m}{sl}{slanted}%
      \show@font{ABCDEFGHIJKL abcdefghijkl 0123456789}{T1}{#8}{m}{sc}{scshape}%
    \end{demoblock}%
  \end{frame}%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Misc
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{xcolor}

\def\PdfLaTeX{Pdf\LaTeX}

\def\siglest{\ttfamily\bfseries\color{blue}}

\mode
<beamer>

  \def\siglest{\ttfamily\bfseries\color{white!80!blue}}

\mode
<all>

\def\sigle#1{{\siglest#1}}

\def\texthd#1{{\color{white!80!blue}\large #1}}
\def\heading#1{\bigskip\par\texthd{#1}\medskip\\}

\def\option{\color{cyan}}